@@ -8,7 +8,14 @@ import socket
 import supybot.callbacks
 import threading
 import time
-import types
+
+# A flag placed on wrapped methods to note we have already wrapped them once.
+SENTINEL = '_sentinel_flag'
+
+
+def already_wrapped(method):
+    """ Return true if it looks like we have already wrapped a target. """
+    return hasattr(method, SENTINEL) or hasattr(method.__func__, SENTINEL)
 
 
 class Fedmsg(supybot.callbacks.Plugin):
@@ -54,6 +61,7 @@ class Injector(threading.Thread):
 
         # TODO -- _duckpunch_announce()
 
+
     def _duckpunch_meetbot(shmelf):
         """ Replace some of meetbot's methods with our own which simply call
         meetbot's original method, and then emit a fedmsg message before
@@ -76,12 +84,17 @@ class Injector(threading.Thread):
         for target_method, topic in tap_points.items():
 
             def wrapper_factory(topic):
-                old_method = getattr(target_cls, target_method).__func__
+                old_method = getattr(target_cls, target_method)
 
                 def wrapper(self, *args, **kw):
                     # Call the target plugin's original code first and save the
                     # result.
-                    result = old_method(self, *args, **kw)
+                    result = old_method.__func__(self, *args, **kw)
+
+                    # Include the owner of the meeting in the chairs dict just
+                    # in case they never explicitly #chair'd themselves.
+                    chairs = self.chairs
+                    chairs[owner] = chairs.get(owner, True)
 
                     # Emit on "org.fedoraproject.prod.meetbot.meeting.start"
                     fedmsg.publish(
@@ -89,7 +102,7 @@ class Injector(threading.Thread):
                         topic=topic,
                         msg=dict(
                             owner=self.owner,
-                            chairs=self.chairs,
+                            chairs=chairs,
                             attendees=self.attendees,
                             url=self.config.filename(url=True),
                             meeting_topic=self._meetingTopic,
@@ -101,7 +114,13 @@ class Injector(threading.Thread):
                     # Return the original result from the target plugin.
                     return result
 
-                return wrapper
+                # Set a flag indicating that we are wrapping the other plugin
+                setattr(wrapper, SENTINEL, True)
+
+                if already_wrapped(old_method):
+                    return old_method
+                else:
+                    return wrapper
 
             # Build the new method and attach it to the target class.
             new_method = wrapper_factory(topic=topic)
